@@ -1,12 +1,12 @@
 /* **************************************************** teo2gdk-pixbuf.h *** *
  * teogdk-pixbuf֤Ѵ饤֥ إåե
  *
- * Copyright (C) 2001 Yasuyuki SUGAYA, <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2004 Yasuyuki SUGAYA, <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-11-20 08:21:21 sugaya>
+ *                                  Time-stamp: <04/09/17 11:13:46 sugaya>
  * ************************************************************************* */
-#ifndef	_TEO2GDK_PIXBUF_H_
-#define	_TEO2GDK_PIXBUF_H_
+#ifndef	__TEO2GDK_PIXBUF_H__
+#define	__TEO2GDK_PIXBUF_H__
 
 #include <teo.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
