@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2001 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-09-18 11:43:46 sugaya>
+ *                                  Time-stamp: <04/09/22 09:45:42 sugaya>
  * ************************************************************************* */
 #include <stdio.h>
 #include <teo.h>
@@ -628,6 +628,8 @@ TeoNormalImageRegion (TEOIMAGE	*src,
   dst_ptr = (TEO_UINT8 *) dst->data;  
   param   = (min != max) ? max - min : (min > 255) ? min : 255;
   min     = (min == max) ? 0 : min;
+  cols	  = ce - cs + 1;
+  plane	  = TeoPlane (src);
   step	  = (TeoWidth (src) - cols) * plane;
   cols	 *= plane;
   switch (TeoType (src)) {
@@ -864,6 +866,7 @@ TeoNormalImagePlaneRegion (TEOIMAGE	*src,
   param   = (min != max) ? max - min : (min > 255) ? min : 255;
   min     = (min == max) ? 0 : min;
   plane	  = TeoPlane (src);
+  cols	  = ce - cs + 1,
   step    = (TeoWidth (src) - cols) * plane;
   switch (TeoType (src)) {
   case (TEO_UNSIGNED):
